DownloadProgress class

Constructors

DownloadProgress({required int downloaded, required int total, required double progress, required DownloadStatus status, String? error, String? filePath})
const

Properties

downloaded int
final
error String?
final
filePath String?
final
hashCode int
The hash code for this object.
no setteroverride
isCancelled bool
no setter
isCompleted bool
no setter
isDownloading bool
no setter
isFailed bool
no setter
isIdle bool
no setter
progress double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status DownloadStatus
final
total int
final

Methods

copyWith({int? downloaded, int? total, double? progress, DownloadStatus? status, String? error, String? filePath}) DownloadProgress
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override